# Generated by Django 3.2.2 on 2021-10-26 17:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0042_delete_personcontactdetail"),
    ]

    operations = [
        migrations.AddField(
            model_name="legislativesession",
            name="active",
            field=models.BooleanField(default=False),
        ),
    ]
