# Generated by Django 3.2.2 on 2021-10-13 19:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0041_personoffice"),
    ]

    operations = [
        migrations.DeleteModel(
            name="PersonContactDetail",
        ),
    ]
