from ..models import State, Chamber, District

MA = State(
    name="Massachusetts",
    abbr="MA",
    capital="Boston",
    capital_tz="America/New_York",
    fips="25",
    unicameral=False,
    legislature_name="Massachusetts General Court",
    legislature_organization_id="ocd-organization/9c4e7b53-9912-4394-a40a-14b5ecdb8aba",
    executive_name="Office of the Governor",
    executive_organization_id="ocd-organization/61a1385f-f512-4d4b-826f-3118c9a775bf",
    division_id="ocd-division/country:us/state:ma",
    jurisdiction_id="ocd-jurisdiction/country:us/state:ma/government",
    url="http://mass.gov",
    lower=Chamber(
        chamber_type="lower",
        name="House",
        organization_id="ocd-organization/ca38ad9c-c3d5-4c4f-bc2f-d885218ed802",
        num_seats=162,
        title="Representative",
        districts=[
            District(
                "10th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_bristol",
                1,
            ),
            District(
                "10th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_essex",
                1,
            ),
            District(
                "10th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_hampden",
                1,
            ),
            District(
                "10th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_middlesex",
                1,
            ),
            District(
                "10th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_norfolk",
                1,
            ),
            District(
                "10th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_plymouth",
                1,
            ),
            District(
                "10th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_suffolk",
                1,
            ),
            District(
                "10th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:10th_worcester",
                1,
            ),
            District(
                "11th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_bristol",
                1,
            ),
            District(
                "11th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_essex",
                1,
            ),
            District(
                "11th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_hampden",
                1,
            ),
            District(
                "11th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_middlesex",
                1,
            ),
            District(
                "11th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_norfolk",
                1,
            ),
            District(
                "11th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_plymouth",
                1,
            ),
            District(
                "11th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_suffolk",
                1,
            ),
            District(
                "11th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:11th_worcester",
                1,
            ),
            District(
                "12th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_bristol",
                1,
            ),
            District(
                "12th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_essex",
                1,
            ),
            District(
                "12th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_hampden",
                1,
            ),
            District(
                "12th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_middlesex",
                1,
            ),
            District(
                "12th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_norfolk",
                1,
            ),
            District(
                "12th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_plymouth",
                1,
            ),
            District(
                "12th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_suffolk",
                1,
            ),
            District(
                "12th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:12th_worcester",
                1,
            ),
            District(
                "13th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:13th_bristol",
                1,
            ),
            District(
                "13th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:13th_essex",
                1,
            ),
            District(
                "13th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:13th_middlesex",
                1,
            ),
            District(
                "13th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:13th_norfolk",
                1,
            ),
            District(
                "13th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:13th_suffolk",
                1,
            ),
            District(
                "13th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:13th_worcester",
                1,
            ),
            District(
                "14th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:14th_bristol",
                1,
            ),
            District(
                "14th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:14th_essex",
                1,
            ),
            District(
                "14th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:14th_middlesex",
                1,
            ),
            District(
                "14th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:14th_norfolk",
                1,
            ),
            District(
                "14th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:14th_suffolk",
                1,
            ),
            District(
                "14th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:14th_worcester",
                1,
            ),
            District(
                "15th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:15th_essex",
                1,
            ),
            District(
                "15th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:15th_middlesex",
                1,
            ),
            District(
                "15th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:15th_norfolk",
                1,
            ),
            District(
                "15th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:15th_suffolk",
                1,
            ),
            District(
                "15th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:15th_worcester",
                1,
            ),
            District(
                "16th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:16th_essex",
                1,
            ),
            District(
                "16th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:16th_middlesex",
                1,
            ),
            District(
                "16th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:16th_suffolk",
                1,
            ),
            District(
                "16th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:16th_worcester",
                1,
            ),
            District(
                "17th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:17th_essex",
                1,
            ),
            District(
                "17th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:17th_middlesex",
                1,
            ),
            District(
                "17th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:17th_suffolk",
                1,
            ),
            District(
                "17th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:17th_worcester",
                1,
            ),
            District(
                "18th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:18th_essex",
                1,
            ),
            District(
                "18th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:18th_middlesex",
                1,
            ),
            District(
                "18th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:18th_suffolk",
                1,
            ),
            District(
                "19th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:19th_worcester",
                1,
            ),
            District(
                "18th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:18th_worcester",
                1,
            ),
            District(
                "19th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:19th_middlesex",
                1,
            ),
            District(
                "19th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:19th_suffolk",
                1,
            ),
            District(
                "1st Barnstable",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_barnstable",
                1,
            ),
            District(
                "1st Berkshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_berkshire",
                1,
            ),
            District(
                "1st Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_bristol",
                1,
            ),
            District(
                "1st Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_essex",
                1,
            ),
            District(
                "1st Franklin",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_franklin",
                1,
            ),
            District(
                "1st Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_hampden",
                1,
            ),
            District(
                "1st Hampshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_hampshire",
                1,
            ),
            District(
                "1st Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_middlesex",
                1,
            ),
            District(
                "1st Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_norfolk",
                1,
            ),
            District(
                "1st Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_plymouth",
                1,
            ),
            District(
                "1st Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_suffolk",
                1,
            ),
            District(
                "1st Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:1st_worcester",
                1,
            ),
            District(
                "20th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:20th_middlesex",
                1,
            ),
            District(
                "21st Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:21st_middlesex",
                1,
            ),
            District(
                "22nd Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:22nd_middlesex",
                1,
            ),
            District(
                "23rd Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:23rd_middlesex",
                1,
            ),
            District(
                "24th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:24th_middlesex",
                1,
            ),
            District(
                "25th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:25th_middlesex",
                1,
            ),
            District(
                "26th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:26th_middlesex",
                1,
            ),
            District(
                "27th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:27th_middlesex",
                1,
            ),
            District(
                "28th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:28th_middlesex",
                1,
            ),
            District(
                "29th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:29th_middlesex",
                1,
            ),
            District(
                "2nd Barnstable",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_barnstable",
                1,
            ),
            District(
                "2nd Berkshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_berkshire",
                1,
            ),
            District(
                "2nd Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_bristol",
                1,
            ),
            District(
                "2nd Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_essex",
                1,
            ),
            District(
                "2nd Franklin",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_franklin",
                1,
            ),
            District(
                "2nd Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_hampden",
                1,
            ),
            District(
                "2nd Hampshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_hampshire",
                1,
            ),
            District(
                "2nd Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_middlesex",
                1,
            ),
            District(
                "2nd Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_norfolk",
                1,
            ),
            District(
                "2nd Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_plymouth",
                1,
            ),
            District(
                "2nd Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_suffolk",
                1,
            ),
            District(
                "2nd Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:2nd_worcester",
                1,
            ),
            District(
                "30th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:30th_middlesex",
                1,
            ),
            District(
                "31st Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:31st_middlesex",
                1,
            ),
            District(
                "32nd Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:32nd_middlesex",
                1,
            ),
            District(
                "33rd Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:33rd_middlesex",
                1,
            ),
            District(
                "34th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:34th_middlesex",
                1,
            ),
            District(
                "35th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:35th_middlesex",
                1,
            ),
            District(
                "36th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:36th_middlesex",
                1,
            ),
            District(
                "37th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:37th_middlesex",
                1,
            ),
            District(
                "3rd Barnstable",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_barnstable",
                1,
            ),
            District(
                "3rd Berkshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_berkshire",
                1,
            ),
            District(
                "3rd Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_bristol",
                1,
            ),
            District(
                "3rd Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_essex",
                1,
            ),
            District(
                "3rd Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_hampden",
                1,
            ),
            District(
                "3rd Hampshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_hampshire",
                1,
            ),
            District(
                "3rd Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_middlesex",
                1,
            ),
            District(
                "3rd Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_norfolk",
                1,
            ),
            District(
                "3rd Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_plymouth",
                1,
            ),
            District(
                "3rd Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_suffolk",
                1,
            ),
            District(
                "3rd Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:3rd_worcester",
                1,
            ),
            District(
                "4th Barnstable",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_barnstable",
                1,
            ),
            District(
                "4th Berkshire",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_berkshire",
                1,
            ),
            District(
                "4th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_bristol",
                1,
            ),
            District(
                "4th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_essex",
                1,
            ),
            District(
                "4th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_hampden",
                1,
            ),
            District(
                "4th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_middlesex",
                1,
            ),
            District(
                "4th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_norfolk",
                1,
            ),
            District(
                "4th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_plymouth",
                1,
            ),
            District(
                "4th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_suffolk",
                1,
            ),
            District(
                "4th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:4th_worcester",
                1,
            ),
            District(
                "5th Barnstable",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_barnstable",
                1,
            ),
            District(
                "5th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_bristol",
                1,
            ),
            District(
                "5th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_essex",
                1,
            ),
            District(
                "5th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_hampden",
                1,
            ),
            District(
                "5th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_middlesex",
                1,
            ),
            District(
                "5th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_norfolk",
                1,
            ),
            District(
                "5th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_plymouth",
                1,
            ),
            District(
                "5th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_suffolk",
                1,
            ),
            District(
                "5th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:5th_worcester",
                1,
            ),
            District(
                "6th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_bristol",
                1,
            ),
            District(
                "6th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_essex",
                1,
            ),
            District(
                "6th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_hampden",
                1,
            ),
            District(
                "6th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_middlesex",
                1,
            ),
            District(
                "6th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_norfolk",
                1,
            ),
            District(
                "6th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_plymouth",
                1,
            ),
            District(
                "6th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_suffolk",
                1,
            ),
            District(
                "6th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:6th_worcester",
                1,
            ),
            District(
                "7th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_bristol",
                1,
            ),
            District(
                "7th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_essex",
                1,
            ),
            District(
                "7th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_hampden",
                1,
            ),
            District(
                "7th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_middlesex",
                1,
            ),
            District(
                "7th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_norfolk",
                1,
            ),
            District(
                "7th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_plymouth",
                1,
            ),
            District(
                "7th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_suffolk",
                1,
            ),
            District(
                "7th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:7th_worcester",
                1,
            ),
            District(
                "8th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_bristol",
                1,
            ),
            District(
                "8th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_essex",
                1,
            ),
            District(
                "8th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_hampden",
                1,
            ),
            District(
                "8th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_middlesex",
                1,
            ),
            District(
                "8th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_norfolk",
                1,
            ),
            District(
                "8th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_plymouth",
                1,
            ),
            District(
                "8th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_suffolk",
                1,
            ),
            District(
                "8th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:8th_worcester",
                1,
            ),
            District(
                "9th Bristol",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_bristol",
                1,
            ),
            District(
                "18th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:18th_essex",
                1,
            ),
            District(
                "9th Essex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_essex",
                1,
            ),
            District(
                "9th Hampden",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_hampden",
                1,
            ),
            District(
                "9th Middlesex",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_middlesex",
                1,
            ),
            District(
                "9th Norfolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_norfolk",
                1,
            ),
            District(
                "9th Plymouth",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_plymouth",
                1,
            ),
            District(
                "9th Suffolk",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_suffolk",
                1,
            ),
            District(
                "9th Worcester",
                "lower",
                "ocd-division/country:us/state:ma/sldl:9th_worcester",
                1,
            ),
            District(
                "Barnstable, Dukes and Nantucket",
                "lower",
                "ocd-division/country:us/state:ma/sldl:barnstable_dukes_and_nantucket",
                1,
            ),
        ],
    ),
    upper=Chamber(
        chamber_type="upper",
        name="Senate",
        organization_id="ocd-organization/1a75ab3a-669b-43fe-ac8d-31a2d6923d9a",
        num_seats=40,
        title="Senator",
        districts=[
            District(
                "Bristol and Norfolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:bristol_and_norfolk",
                1,
            ),
            District(
                "Cape and Islands",
                "upper",
                "ocd-division/country:us/state:ma/sldu:cape_and_islands",
                1,
            ),
            District(
                "Fifth Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:5th_middlesex",
                1,
            ),
            District(
                "First Bristol and Plymouth",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_bristol_and_plymouth",
                1,
            ),
            District(
                "First Essex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_essex",
                1,
            ),
            District(
                "First Essex and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_essex_and_middlesex",
                1,
            ),
            District(
                "First Hampden and Hampshire",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_hampden_and_hampshire",
                1,
            ),
            District(
                "First Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_middlesex",
                1,
            ),
            District(
                "First Middlesex and Norfolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_middlesex_and_norfolk",
                1,
            ),
            District(
                "First Plymouth and Bristol",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_plymouth_and_bristol",
                1,
            ),
            District(
                "First Suffolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_suffolk",
                1,
            ),
            District(
                "First Suffolk and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_suffolk_and_middlesex",
                1,
            ),
            District(
                "First Worcester",
                "upper",
                "ocd-division/country:us/state:ma/sldu:1st_worcester",
                1,
            ),
            District(
                "Fourth Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:4th_middlesex",
                1,
            ),
            District(
                "Hampden", "upper", "ocd-division/country:us/state:ma/sldu:hampden", 1
            ),
            District(
                "Berkshire, Hampshire, Franklin and Hampden",
                "upper",
                "ocd-division/country:us/state:ma/sldu:berkshire_hampshire_franklin_and_hampden",
                1,
            ),
            District(
                "Middlesex and Suffolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:middlesex_and_suffolk",
                1,
            ),
            District(
                "Middlesex and Worcester",
                "upper",
                "ocd-division/country:us/state:ma/sldu:middlesex_and_worcester",
                1,
            ),
            District(
                "Norfolk, Bristol and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:norfolk_bristol_and_middlesex",
                1,
            ),
            District(
                "Norfolk, Bristol and Plymouth",
                "upper",
                "ocd-division/country:us/state:ma/sldu:norfolk_bristol_and_plymouth",
                1,
            ),
            District(
                "Norfolk and Plymouth",
                "upper",
                "ocd-division/country:us/state:ma/sldu:norfolk_and_plymouth",
                1,
            ),
            District(
                "Norfolk and Suffolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:norfolk_and_suffolk",
                1,
            ),
            District(
                "Plymouth and Barnstable",
                "upper",
                "ocd-division/country:us/state:ma/sldu:plymouth_and_barnstable",
                1,
            ),
            District(
                "Plymouth and Norfolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:plymouth_and_norfolk",
                1,
            ),
            District(
                "Second Bristol and Plymouth",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_bristol_and_plymouth",
                1,
            ),
            District(
                "Second Essex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_essex",
                1,
            ),
            District(
                "Second Essex and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_essex_and_middlesex",
                1,
            ),
            District(
                "Second Hampden and Hampshire",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_hampden_and_hampshire",
                1,
            ),
            District(
                "Second Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_middlesex",
                1,
            ),
            District(
                "Second Middlesex and Norfolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_middlesex_and_norfolk",
                1,
            ),
            District(
                "Second Plymouth and Bristol",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_plymouth_and_bristol",
                1,
            ),
            District(
                "Second Suffolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_suffolk",
                1,
            ),
            District(
                "Second Suffolk and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_suffolk_and_middlesex",
                1,
            ),
            District(
                "Second Worcester",
                "upper",
                "ocd-division/country:us/state:ma/sldu:2nd_worcester",
                1,
            ),
            District(
                "Third Essex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:3rd_essex",
                1,
            ),
            District(
                "Third Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:3rd_middlesex",
                1,
            ),
            District(
                "Worcester and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:worcester_and_middlesex",
                1,
            ),
            District(
                "Worcester and Norfolk",
                "upper",
                "ocd-division/country:us/state:ma/sldu:worcester_and_norfolk",
                1,
            ),
            District(
                "Worcester, Hampden, Hampshire and Middlesex",
                "upper",
                "ocd-division/country:us/state:ma/sldu:worcester_hampden_hampshire_and_middlesex",
                1,
            ),
            District(
                "Hampshire, Franklin and Worcester",
                "upper",
                "ocd-division/country:us/state:ma/sldu:hampshire_franklin_and_worcester",
                1,
            ),
        ],
    ),
)
