# Generated by Django 3.0.5 on 2020-09-14 10:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0018_auto_20200914_1032"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="billabstract",
            name="date",
        ),
    ]
