# Generated by Django 3.0.5 on 2020-04-28 15:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("data", "0007_auto_20200423_1416")]

    operations = [
        migrations.AddField(
            model_name="person",
            name="current_state",
            field=models.CharField(default="", max_length=2),
        )
    ]
